﻿using System;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// Excelファイルの読み込みクラス
    /// </summary>
    class ExcelReader
    {
        /// <summary>
        /// Excelファイルからランキングデータを読み込む
        /// </summary>
        /// <returns></returns>
        static public List<RankingData> ReadRankingData(string path)
        {
            List<RankingData> rankingList = new List<RankingData>();
            ExcelCom excel = null;

            try
            {
                excel = new ExcelCom();
                excel.OpenFile(path);

                int row = 2;

                while (!String.IsNullOrEmpty(excel.GetValue(row, 1)))
                {
                    RankingData rank = new RankingData();
                    rank.Rank = Int32.Parse(excel.GetValue(row, 1));
                    rank.Mark = excel.GetValue(row, 2);
                    rank.DiffRank = Int32.Parse(excel.GetValue(row, 3));
                    rank.RankStat = excel.GetValue(row, 4);
                    rank.VideoId = excel.GetValue(row, 5);
                    rank.Title = excel.GetValue(row, 6);
                    rank.Pts = Decimal.Parse(excel.GetValue(row, 7));
                    rank.Mylist = Decimal.Parse(excel.GetValue(row, 8));
                    rank.Play = Decimal.Parse(excel.GetValue(row, 9));
                    rank.Author = excel.GetValue(row, 10);
                    rank.Date = DateTime.Parse(excel.GetValue(row, 11));

                    object v = excel.GetValue(row, 12);
                    rank.Remarks = (v == null) ? "" : v.ToString();

                    rankingList.Add(rank);

                    row++;
                }
            }
            catch (Exception ex)
            {
                throw ex;
            }
            finally
            {
                if (excel != null)
                {
                    excel.Quit();
                    excel.Dispose();
                }
            }

            return rankingList;
        }
    }

    /// <summary>
    /// ランキング情報
    /// </summary>
    internal struct RankingData
    {
        /// <summary>順位</summary>
        public int Rank { get; set; }

        /// <summary>ランク上下識別文字</summary>
        public string Mark { get; set; }

        /// <summary>先週からの順位差</summary>
        public int DiffRank { get; set; }

        /// <summary>変動</summary>
        public string RankStat { get; set; }

        /// <summary>動画ID</summary>
        public string VideoId { get; set; }

        /// <summary>動画タイトル</summary>
        public string Title { get; set; }

        /// <summary>点数</summary>
        public decimal Pts { get; set; }

        /// <summary>マイリスト登録数</summary>
        public decimal Mylist { get; set; }

        /// <summary>再生数</summary>
        public decimal Play { get; set; }

        /// <summary>作者</summary>
        public string Author { get; set; }

        /// <summary>投稿日</summary>
        public DateTime Date { get; set; }

        /// <summary>補足</summary>
        public string Remarks { get; set; }
    }
}
