﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Windows.Forms;

namespace SyumasGen
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// 実行ボタンクリック
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void execButton_Click(object sender, EventArgs e)
        {
            if (fileText.Text == "")
            {
                MessageBox.Show("ファイルを入力してください。");
                return;
            }

            // 設定ファイル読み込み
            string iniPath = Path.Combine(Application.StartupPath, "Settings.ini");
            Settings settings = new Settings();
            settings.ReadIniFile(iniPath);

            // Excelファイル読み込み
            string excelPath = Path.Combine(Application.StartupPath, fileText.Text);
            List<RankingData> rankingList = ExcelReader.ReadRankingData(excelPath);

            // グラフィックス描画オブジェクト生成
            try
            {
                using (ImageGenerator gen = new ImageGenerator())
                {
                    foreach (var rankingData in rankingList)
                    {
                        // フレームの生成
                        string filaPath1 = Path.Combine(Application.StartupPath, @"frame\rank" + rankingData.Rank.ToString() + ".png");
                        gen.DrawFrame(rankingData, settings, filaPath1);

                        // "xx Rank Up!"とかの画像の生成
                        string filePath2 = Path.Combine(Application.StartupPath, @"frame\text" + rankingData.Rank.ToString() + ".png");
                        gen.DrawRankInfoText(rankingData, settings, filePath2);
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, "エラーが発生しました：\n" + ex.ToString(), "エラー", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            MessageBox.Show(this, "完了しました。", "完了", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        /// <summary>
        /// 参照ボタンクリック
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void fileBrowseButton_Click(object sender, EventArgs e)
        {
            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                fileText.Text = openFileDialog.FileName;
            }
        }
    }
}
